@@ -1,4 +1,4 @@
-from typing import Iterable, List, Union, Tuple
+from typing import Iterable, List, Union
 
 import numpy as np
 
@@ -21,10 +21,10 @@ class SliceCollection(FDSDataCollection):
     def filter_by_quantity(self, quantity: Union[str, Quantity]):
         """Filters all slices by a specific quantity.
         """
-        if type(quantity) != str:
+        if type(quantity) == Quantity:
             quantity = quantity.name
         return SliceCollection(x for x in self if x.quantity.name.lower() == quantity.lower()
-                               or x.quantity.label.lower() == quantity.lower())
+                               or x.quantity.short_name.lower() == quantity.lower())
 
     def get_by_id(self, slice_id: str):
         """Get the slice with corresponding id if it exists.
